@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # lesspipe.sh, a preprocessor for less
-lesspipe_version=2.09
+lesspipe_version=2.12
 # Author: Wolfgang Friebel (wp.friebel AT gmail.com)
 #( [[ -n 1 && -n 2 ]] ) > /dev/null 2>&1 || exec zsh -y --ksh-arrays -- "$0" ${1+"$@"}
 
@@ -25,8 +25,8 @@ filetype () {
 		declare t
 		t=$(nexttmp)
 		head -c 1000000 > "$t" 2>/dev/null
+		[[ -z $fileext ]] && fname="$t" || fname="$fileext"
 		set "$t" "$2"
-		fname="$fileext"
 	fi
 	fext=$(fileext "$fname")
 	### get file type from mime type
@@ -76,9 +76,11 @@ filetype () {
 		mp3)
 			[[ $ftype == mpeg ]] && ftype=mp3 ;;
 		jsx)
-			[[ $fcat == text ]] && ftype=$fext ;;
+			[[ $fcat == text ]] && ftype=jsx ;;
 		tsx)
 			[[ $fcat == text ]] && ftype=typescript-jsx ;;
+		csv)
+			[[ $fcat == text ]] && ftype=csv ;;
 	esac
 	### get file type from 'file' command for an unspecific result
 	if [[ "$fcat" == message && $ftype == plain ]]; then
@@ -180,7 +182,7 @@ separatorline () {
 }
 
 nexttmp () {
-	declare new="$tmpdir/lesspipe.$RANDOM"
+	declare new="$tmpdir/lesspipe.$RANDOM.${ft%%:*}"
 	echo "$new"
 }
 
@@ -369,6 +371,7 @@ get_unpack_cmd () {
 			{ has_cmd bsdtar && prog=bsdtar; } ||
 			{ has_cmd cabextract && prog=cabextract; } ;;
 		7z-compressed)
+			{ has_cmd 7zz && prog=7zz; } ||
 			{ has_cmd 7zr && prog=7zr; } ||
 			{ has_cmd 7z && prog=7z; } ||
 			{ has_cmd 7za && prog=7za; } ;;
@@ -383,7 +386,9 @@ get_unpack_cmd () {
 	if [[ -n ${cmd[*]} ]]; then
 		[[ -n "$file2" ]] && file2= && return
 		msg "use ${x}_file${sep}contained_file to view a file in the archive"
-		has_cmd archive_color && colorizer=(archive_color)
+		if [[ $COLOR = --color=always ]]; then
+			has_cmd archive_color && colorizer=(archive_color)
+		fi
 	fi
 }
 
@@ -441,6 +446,8 @@ has_colorizer () {
 			if [[ -r "$HOME/.config/bat/config" ]]; then
 				grep -q -e '^--style' "$HOME/.config/bat/config" || opt+=(--style="${style%% *}")
 				grep -q -e '^--theme' "$HOME/.config/bat/config" || opt+=(--theme="${theme%% *}")
+			else
+				opt+=(--style="${style%% *}" --theme="${theme%% *}")
 			fi
 			opt+=("$COLOR" --paging=never "$1") ;;
 		pygmentize)
@@ -510,22 +517,18 @@ isfinal () {
 				{ has_cmd pandoc && istemp "pptx2md --disable-image --disable-wmf \
 					-o $t2" "$1" && cmd=(pandoc -f markdown -t plain "$t2"); }; } ||
 			{ has_cmd libreoffice && has_htmlprog && cmd=(isoffice "$1" ppt); } ;;
-		xlsx)
-			{ has_cmd xlscat && cmd=(istemp xlscat "$1"); } ||
-			{ has_cmd libreoffice && has_htmlprog && cmd=(isoffice "$1" xlsx); } ;;
+		xlsx|ods)
+			{ has_cmd xlscat && cmd=(istemp "xlscat -L -R all" "$1"); } ||
+			{ has_cmd libreoffice && has_htmlprog && cmd=(isoffice "$1" "$x"); } ;;
 		odt)
 			{ has_cmd odt2txt && cmd=(istemp odt2txt "$1"); } ||
 			{ has_cmd pandoc && cmd=(pandoc -f odt -t plain "$1"); } ||
 			{ has_cmd libreoffice && cmd=(isoffice2 "$1"); } ;;
 		odp)
 			{ has_cmd libreoffice && has_htmlprog && cmd=(isoffice "$1" odp); } ;;
-		ods)
-			{ has_cmd xlscat && t=$t.ods && cat "$1" > "$t" && cmd=(xlscat "$t"); } ||
-			{ has_cmd libreoffice && has_htmlprog && cmd=(isoffice "$1" ods); } ;;
 		msword)
 			t="$1"; [[ "$t" == - ]] && t=/dev/stdin
 			{ has_cmd wvText && cmd=(istemp wvText "$t" /dev/stdout); } ||
-			{ has_cmd antiword && cmd=(antiword "$1"); } ||
 			{ has_cmd catdoc && cmd=(catdoc "$1"); } ||
 			{ has_cmd libreoffice && cmd=(isoffice2 "$1"); } ;;
 		ms-powerpoint)
@@ -573,7 +576,7 @@ isfinal () {
 		csr)
 			has_cmd openssl && cmd=(istemp "openssl req -text -noout -in" "$1") ;;
 		pgp)
-			has_cmd gpg && cmd=(gpg -d "$1") ;;
+			has_cmd gpg && cmd=(gpg --decrypt --quiet --no-tty --batch --yes "$1") ;;
 		plist)
 			{ has_cmd plistutil && cmd=(istemp "plistutil -i" "$1"); } ||
 			{ has_cmd plutil && cmd=(istemp "plutil -p" "$1"); } ;;
@@ -583,7 +586,10 @@ isfinal () {
 			has_cmd ccze && [[ $COLOR = *always ]] && ccze -A < "$1"
 			return ;;
 		csv)
-			{ has_cmd column && cmd=(column -o "|" -s "	,;" -t "$1"); } ||
+			msg "type -S<ENTER> for better display of very wide tables"
+			{ has_cmd csvtable && csvtable -h >/dev/null 2>&1 && cmd=(csvtable "$1"); } ||
+			{ has_cmd csvlook && cmd=(csvlook -S "$1"); } ||
+			{ has_cmd column && cmd=(istemp "column -s	,; -t" "$1"); } ||
 			{ has_cmd pandoc && cmd=(pandoc -f csv -t plain "$1"); } ;;
 		json)
 			[[ $COLOR = *always ]] && opt=(-C .) || opt=(.)
@@ -650,7 +656,7 @@ isarchive () {
 				istemp cabextract2 "$2" "$3" ;;
 			isoinfo)
 				istemp "isoinfo -i" "$2" "-x$3" ;;
-			7za|7zr)
+			7zz|7za|7zr)
 				istemp "$prog e -so" "$2" "$3"
 		esac
 	else
@@ -672,7 +678,7 @@ isarchive () {
 				isoinfo -d -i "$t"| grep -E '^Joliet' && joliet=J
 				separatorline
 				isoinfo -fR"$joliet" -i "$t" ;;
-			7za|7zr)
+			7zz|7za|7zr)
 				istemp "$prog l" "$2"
 		esac
 	fi
@@ -782,9 +788,8 @@ ishtml () {
 	has_cmd elinks && nodash "elinks -dump -force-html" "$1" && return ||
 	has_cmd w3m && handle_w3m "$1" && return ||
 	has_cmd lynx && lynx -force_html -dump "$arg1" && return ||
-	# different incompatible versions with the name html2text may let this fail
-	[[ "$1" == https://* ]] && return
-	html2text -utf8 || html2text -from_encoding utf-8
+	# different versions of html2text existing, therefore no encoding handling
+	[[ "$1" == https://* ]] && return ||
 	has_cmd html2text && nodash html2text "$1"
 }
 
@@ -821,7 +826,7 @@ if [[ $LESSOPEN == *\|-* && $1 == - ]]; then
 	nexttmp >/dev/null
 fi
 
-if [[ -z "$1" ]]; then
+if [[ -z "$1" && "$0" == */lesspipe.sh ]]; then
 	[[ "$0" == /* ]] || pat=$(pwd)/
 	if [[ "$SHELL" == *csh ]]; then
 		echo "setenv LESSOPEN \"|$pat$0 %s\""
@@ -835,5 +840,10 @@ else
 	elif has_cmd lessfilter; then
 		lessfilter "$1" && exit 0
 	fi
-	show "$@"
+	if [[ -z "$1" ]]; then
+		LESSQUIET=1
+		show -
+	else
+		show "$@"
+	fi
 fi
